@@ -1,4 +1,11 @@
-"""This module reads the configuration file."""
+"""A module to read/define configuration and logging.
+
+This module contains two global instances which should
+be accessed only through their getter/setter methods.
+These instances are not threadsafe: they should be
+updated only prior to spawning any threads.
+
+"""
 
 import configparser
 from enum import Enum
@@ -17,10 +24,15 @@ from typing import (  # noqa
 from .docstring.base import DocstringStyle
 
 
-# TODO: Configure this logger and allow the user to specify
-# the whether they want warnings.
-logging.basicConfig(level=logging.ERROR)
-logger = logging.getLogger('darglint')
+def get_logger():  # type: () -> Logger
+    """Get the default logger for darglint.
+
+    Returns:
+        The default logger for darglint.
+
+    """
+    return logging.getLogger('darglint')
+
 
 POSSIBLE_CONFIG_FILENAMES = (
     '.darglint',
@@ -59,12 +71,69 @@ class Strictness(Enum):
     # Require everything.
     FULL_DESCRIPTION = 3
 
+    @classmethod
+    def from_string(cls, strictness):
+        strictness = strictness.lower().strip()
+        if strictness in {'short_description', 'short'}:
+            return cls.SHORT_DESCRIPTION
+        if strictness in {'long_description', 'long'}:
+            return cls.LONG_DESCRIPTION
+        if strictness in {'full_description', 'full'}:
+            return cls.FULL_DESCRIPTION
+
+        raise Exception(
+            'Unrecognized strictness amount "{}".  '.format(strictness) +
+            'Should be one of {"short", "long", "full"}'
+        )
+
+
+class AssertStyle(Enum):
+    """Describes how to handle assertions."""
+    RAISE = 1
+    LOG = 2
+
+
+class LogLevel(Enum):
+    """Describes the level of error which should be logged.
+
+    These levels correspond to the levels in logging.
+    This wrapper primarily serves as a means of conveniently
+    parsing the levels, while maintaining the same interface
+    as other options.
+
+    """
+    CRITICAL = logging.CRITICAL
+    ERROR = logging.ERROR
+    WARNING = logging.WARNING
+    INFO = logging.INFO
+    DEBUG = logging.DEBUG
+
+    @classmethod
+    def from_string(cls, level):
+        # type: (str) -> LogLevel
+        normalized_level = level.lower().strip()
+        if normalized_level == 'critical':
+            return cls.CRITICAL
+        elif normalized_level == 'error':
+            return cls.ERROR
+        elif normalized_level == 'warning':
+            return cls.WARNING
+        elif normalized_level == 'info':
+            return cls.INFO
+        elif normalized_level == 'debug':
+            return cls.DEBUG
+        else:
+            raise ValueError('Unrecognized log level, "{}"'.format(
+                level
+            ))
+
 
 class Configuration(object):
 
     def __init__(self, ignore, message_template, style, strictness,
-                 ignore_regex=None, enable=[], indentation=4):
-        # type: (List[str], Optional[str], DocstringStyle, Strictness, Optional[str], List[str], int) -> None  # noqa: E501
+                 ignore_regex=None, enable=[], indentation=4,
+                 assert_style=AssertStyle.LOG, log_level=LogLevel.CRITICAL):
+        # type: (List[str], Optional[str], DocstringStyle, Strictness, Optional[str], List[str], int, AssertStyle) -> None  # noqa: E501
         """Initialize the configuration object.
 
         Args:
@@ -76,6 +145,8 @@ class Configuration(object):
                 functions/methods by name.
             enable: A list of of error codes that are disabled by default.
             indentation: The number of spaces to count as an indent.
+            assert_style: The assert style to use (e.g. log on failed
+                assertions, or raise exception on failed assertions.)
 
         """
         self._enable = enable
@@ -86,6 +157,40 @@ class Configuration(object):
         self.errors_to_ignore = self._get_errors_to_ignore()
         self.ignore_regex = ignore_regex
         self.indentation = indentation
+        self.assert_style = assert_style
+        self.log_level = log_level
+
+    @property
+    def log_level(self):
+        # type: () -> LogLevel
+        return self._log_level
+
+    @log_level.setter
+    def log_level(self, log_level):
+        # type: (LogLevel) -> None
+        self._log_level = log_level
+        logger = get_logger()
+        logger.setLevel(log_level.value)
+
+    def __str__(self):
+        # type: () -> str
+        return '\n'.join([
+            'message_template={message_template}',
+            'style={style}',
+            'strictness={strictness}',
+            'indentation={indentation}',
+            'ignore={errors_to_ignore}',
+            'ignore_regex={ignore_regex}',
+        ]).format(**self.__dict__)
+
+    @classmethod
+    def get_default_instance(cls):
+        return cls(
+            ignore=list(),
+            message_template=None,
+            style=DocstringStyle.GOOGLE,
+            strictness=Strictness.FULL_DESCRIPTION,
+        )
 
     @property
     def enable(self):
@@ -147,6 +252,7 @@ def load_config_file(filename):  # type: (str) -> Configuration
     style = DocstringStyle.GOOGLE
     strictness = Strictness.FULL_DESCRIPTION
     indentation = 4
+    log_level = LogLevel.CRITICAL
     if 'darglint' in config.sections():
         if 'ignore' in config['darglint']:
             errors = config['darglint']['ignore']
@@ -161,32 +267,13 @@ def load_config_file(filename):  # type: (str) -> Configuration
         if 'ignore_regex' in config['darglint']:
             ignore_regex = config['darglint']['ignore_regex']
         if 'docstring_style' in config['darglint']:
-            raw_style = config['darglint']['docstring_style'].lower().strip()
-            if raw_style == 'google':
-                style = DocstringStyle.GOOGLE
-            elif raw_style == 'sphinx':
-                style = DocstringStyle.SPHINX
-            elif raw_style == 'numpy':
-                style = DocstringStyle.NUMPY
-            else:
-                raise Exception(
-                    'Unrecognized style.  Should be one of {}'.format(
-                        [x.name for x in DocstringStyle]
-                    )
-                )
+            raw_style = config['darglint']['docstring_style']
+            style = DocstringStyle.from_string(raw_style)
+
         if 'strictness' in config['darglint']:
-            raw_strictness = config['darglint']['strictness'].lower().strip()
-            if raw_strictness in {'short_description', 'short'}:
-                strictness = Strictness.SHORT_DESCRIPTION
-            elif raw_strictness in {'long_description', 'long'}:
-                strictness = Strictness.LONG_DESCRIPTION
-            elif raw_strictness in {'full_description', 'full'}:
-                strictness = Strictness.FULL_DESCRIPTION
-            else:
-                raise Exception(
-                    'Unrecognized stricteness amount.  '
-                    'Should be one of {"short", "long", "full"}'
-                )
+            raw_strictness = config['darglint']['strictness']
+            strictness = Strictness.from_string(raw_strictness)
+
         if 'indentation' in config['darglint']:
             try:
                 indentation = int(config['darglint']['indentation'])
@@ -197,6 +284,9 @@ def load_config_file(filename):  # type: (str) -> Configuration
                         config['darglint']['indentation']
                     )
                 )
+
+        if 'log_level' in config['darglint']:
+            log_level = LogLevel.from_string(config['darglint']['log_level'])
     return Configuration(
         ignore=ignore,
         message_template=message_template,
@@ -250,7 +340,7 @@ def find_config_file_in_path(path):  # type: (str) -> Optional[str]
                 if 'darglint' in config.sections():
                     return fully_qualified_path
             except configparser.ParsingError:
-                logger.error('Unable to parse file {}'.format(
+                get_logger().error('Unable to parse file {}'.format(
                     fully_qualified_path
                 ))
     return None
@@ -272,7 +362,7 @@ def find_config_file():  # type: () -> Optional[str]
     return None
 
 
-def get_config():  # type: () -> Configuration
+def get_config_from_file():  # type: () -> Configuration
     """Locate the configuration file and return its Configuration.
 
     Returns:
@@ -282,20 +372,25 @@ def get_config():  # type: () -> Configuration
     """
     filename = find_config_file()
     if filename is None:
-        return Configuration(
-            ignore=list(),
-            message_template=None,
-            style=DocstringStyle.GOOGLE,
-            strictness=Strictness.FULL_DESCRIPTION,
-        )
+        return Configuration.get_default_instance()
     return load_config_file(filename)
 
 
-def get_logger():  # type: () -> Logger
-    """Get the default logger for darglint.
+# The global instance of the config file to use.
+_config = get_config_from_file()
+
+
+def get_config():
+    """Get the global instance of the configuration.
+
+    This instance is not threadsafe, and should only
+    be updated in the initial launching script.
+    I considered adding a mutability option, to make
+    this more explicit, but I think it's obvious enough
+    that you shouldn't modify the configuration elsewhere.
 
     Returns:
-        The default logger for darglint.
+        A global configuration instance.
 
     """
-    return logger
+    return _config
