@@ -15,12 +15,14 @@ from .function_description import (
 )
 from .integrity_checker import IntegrityChecker
 from .config import (
-    Configuration,
     get_config,
+    get_logger,
+    LogLevel,
     Strictness,
 )
 from .docstring.base import DocstringStyle
 import darglint.errors
+from darglint.error_report import ErrorReport
 
 
 # ---------------------- ARGUMENT PARSER -----------------------------
@@ -136,23 +138,41 @@ parser.add_argument(
         'guide, you would set --indentation=2.'
     ),
 )
+parser.add_argument(
+    '--log-level',
+    '-l',
+    type=str,
+    default=None,
+    choices=[
+        'CRITICAL',
+        'ERROR',
+        'WARNING',
+        'INFO',
+        'DEBUG',
+    ],
+    help=(
+        'The level at which to log.  Can help with debugging '
+        'when something strange is happening.  The default '
+        'level, CRITICAL, means that only the most severe of '
+        'errors will be logged.  Assertions are logged at the '
+        'ERROR level.'
+    )
+)
 
 # ---------------------- MAIN SCRIPT ---------------------------------
 
 
 def get_error_report(filename,
                      verbosity,
-                     config,
                      raise_errors_for_syntax,
                      message_template=None,
                      ):
-    # type: (str, int, Configuration, bool, str) -> str
+    # type: (str, int, bool, str) -> str
     """Get the error report for the given file.
 
     Args:
         filename: The name of the module to check.
         verbosity: The level of verbosity, in the range [1, 3].
-        config: The configuration for the error report.
         raise_errors_for_syntax: True if we want parser errors
             to propagate up (crashing darglint.)  This is useful
             if we are developing on darglint -- we can get the stack
@@ -165,19 +185,23 @@ def get_error_report(filename,
 
     """
     program = read_program(filename)
-    tree = ast.parse(program)
-    functions = get_function_descriptions(tree)
-    checker = IntegrityChecker(
-        config,
-        raise_errors=raise_errors_for_syntax,
-    )
-    for function in functions:
-        checker.schedule(function)
-    return checker.get_error_report_string(
-        verbosity,
-        filename,
-        message_template=message_template,
-    )
+    try:
+        tree = ast.parse(program)
+        functions = get_function_descriptions(tree)
+        checker = IntegrityChecker(
+            raise_errors=raise_errors_for_syntax,
+        )
+        for function in functions:
+            checker.schedule(function)
+        return checker.get_error_report_string(
+            verbosity,
+            filename,
+            message_template=message_template,
+        )
+    except SyntaxError as e:
+        error = darglint.errors.PythonSyntaxError(e)
+        report = ErrorReport([error], filename, verbosity, message_template)
+        return str(report)
 
 
 def print_error_list():
@@ -191,7 +215,7 @@ def print_error_list():
 
 
 def print_version():
-    print('1.2.2')
+    print('1.5.4')
 
 
 def main():
@@ -251,12 +275,14 @@ def main():
         elif args.strictness == 'full':
             config.strictness = Strictness.FULL_DESCRIPTION
 
+        if args.log_level:
+            config.log_level = LogLevel.from_string(args.log_level)
+
         raise_errors_for_syntax = args.raise_syntax or False
         for filename in files:
             error_report = get_error_report(
                 filename,
                 args.verbosity,
-                config,
                 raise_errors_for_syntax,
                 message_template=args.message_template,
             )
@@ -267,7 +293,8 @@ def main():
         # Exit with status 129 regardless of whether user wants a
         # exit code or not -- darglint failed, and it should
         # look like it failed.
-        print(exc, file=sys.stderr)
+        logger = get_logger()
+        logger.critical(exc)
         sys.exit(129)
     if encountered_errors and exit_code:
         sys.exit(1)
