@@ -104,6 +104,27 @@ class DarglintError(BaseException):
             raise NotImplementedError
 
 
+class PythonSyntaxError(DarglintError):
+    """Describes a syntax error in parsing the python module.."""
+
+    error_code = 'DAR000'
+    description = (
+        'Failed to parse file due to syntax error.'
+    )
+
+    def __init__(self, source):
+        # type: (SyntaxError) -> None  # noqa: E501
+        """Instantiate the error's message.
+
+        Args:
+            source: The syntax error which was raised by ast.
+
+        """
+        self.general_message = 'Python syntax error'
+        self.terse_message = 's {}'.format(source)
+        self.line_numbers = (source.lineno, source.lineno)
+
+
 class GenericSyntaxError(DarglintError):
     """Describes that something went wrong in parsing the docstring."""
 
@@ -200,6 +221,34 @@ class ExcessNewlineError(DarglintError):
         )
 
 
+class EmptyTypeError(DarglintError):
+    """Describes when an item has parentheses, but no type."""
+
+    error_code = 'DAR005'
+    description = (
+        'The item contains a type section (parentheses), but no type.'
+    )
+
+    def __init__(self, function, message, line_numbers=None):
+        # type: (Union[ast.FunctionDef, ast.AsyncFunctionDef], str, Tuple[int, int]) -> None  # noqa: E501
+        """Instantiate the error's message.
+
+        Args:
+            function: An ast node for the function.
+            message: The parser error's message.
+            line_numbers: The line numbers where this error occurs.
+                Unused.
+
+        """
+        self.general_message = 'Empty type'
+        self.terse_message = 'e {}'.format(message)
+
+        super(EmptyTypeError, self).__init__(
+            function,
+            line_numbers=line_numbers,
+        )
+
+
 class MissingParameterError(DarglintError):
     """Describes when a docstring is missing a parameter in the definition."""
 
@@ -308,6 +357,29 @@ class ParameterTypeMissingError(DarglintError):
         )
 
 
+class ParameterMalformedError(DarglintError):
+    """Describes when an argument type is malformed."""
+
+    error_code = 'DAR105'
+    description = (
+        'The docstring parameter type is malformed. '
+        'Expected parameter type to match syntax from PEP484. '
+        'If your parameter contains parentheses, you may want '
+        'to switch them to brackets.  E.g. `Union[str, int]`.'
+    )
+
+    def __init__(self, function, name, line_numbers=None):
+        # type: (Union[ast.FunctionDef, ast.AsyncFunctionDef], str, Tuple[int, int]) -> None
+        self.general_message = 'Parameter type malformed.'
+        self.terse_message = ' #{}: type malformed'.format(
+            name
+        )
+        self.name = name
+        super(ParameterMalformedError, self).__init__(
+            function,
+            line_numbers=line_numbers,
+        )
+
 
 class MissingReturnError(DarglintError):
     """Describes when a docstring is missing a return from definition."""
