@@ -60,6 +60,10 @@ def _get_arguments(fn):
         else:
             types.append(None)
 
+    if hasattr(fn.args, 'posonlyargs'):
+        for arg in fn.args.posonlyargs:
+            add_arg_by_name(arg.arg, arg)
+
     for arg in fn.args.args:
         add_arg_by_name(arg.arg, arg)
 
@@ -106,6 +110,8 @@ def _walk(fun, skip):
             queue.extendleft(curr.body)
         if hasattr(curr, 'handlers'):
             queue.extendleft(curr.handlers)
+        if hasattr(curr, 'orelse'):
+            queue.extendleft(curr.orelse)
         yield curr
 
 
@@ -248,6 +254,13 @@ def _get_exceptions_raised(fn):  # type: (Union[ast.FunctionDef, ast.AsyncFuncti
     return visitor.exceptions
 
 
+def _raises_assert(fn):
+    # type: (Union[ast.FunctionDef, ast.AsyncFunctionDef]) -> bool  # noqa: E501
+    for node in ast.walk(fn):
+        if isinstance(node, ast.Assert):
+            return True
+    return False
+
 def _get_return_type(fn):
     # type: (Union[ast.FunctionDef, ast.AsyncFunctionDef]) -> Optional[str]
     if fn.returns is not None and hasattr(fn.returns, 'id'):
@@ -332,6 +345,7 @@ class FunctionDescription(object):
             msg = '{}: {}'.format(self.name, ex)
             logger.debug(msg)
         self.variables = _get_all_variable_names(function)
+        self.raises_assert = _raises_assert(function)
 
 
 def get_function_descriptions(program):
